      subroutine kuv (m,np,nband,uo3,uo2,uh2o,uo3s,uo2s,
     * uh2os,acuv)
!      
!  Parameterizations of Fomin and Correa, 2005:  
!  The subroutine is written by Tarasova Aug. 2005
!     uv and visible solar spectrum, 4 intervals
!                     input parameters:
!     m - number of model grid points
!     np - number of levels
!     nband - number of spectral intervals
!    uo3(m,np),uo2(m,np),uh2o(m,np) - concentration of O3,O2,H2O  in molec/(cm2 km)
!    divided by 1.0e17, 1.0e22, and 1.0e21, respectively
!    uo3s(m,np),uo2s(m,np),uh2os(m,np) - amount of O3,O2,H2O  in molec/(cm2)
!    at the solar beam divided by 1.0e17, 1.0e22, and 1.0e21, respectively
!                     output parameter: 
!    acuv(m,np,nband) - volume absorption coefficient (km-1)
!      
      implicit none             
      integer m, np, nband
      integer i,k,l
      real uo3(m,np), uo2(m,np), uh2o(m,np)
      real uo3s(m,np), uo2s(m,np), uh2os(m,np)       
      real acuv(m,np,nband)
      real u1o3(22),ac1o3l(22),u1o2(7),ac1o2l(7)
      real u2o3(8),ac2o3l(8),u4o2(8),ac4o2l(8)      
      real ac1o3,ac1o2,ac2o3,ac4o2      
!      
      data u1o3/1.0e-6,0.02,0.05,0.1,0.2,0.4,0.6,1.0,2.0,3.0,4.0, 
     * 5.0,6.0,7.0,9.0,15.0,20.0,30.0,100.0,200.0,250.,400.0/      
      data ac1o3l/0.365,0.365,0.362,0.355,0.345,0.32,0.3,0.26,
     * 0.185,0.15,0.12,0.105,0.095,0.09,0.08,0.063,0.057,0.047,0.032,
     * 0.026,0.023,0.005/
      data u1o2/1.0e-7,0.1,1.0,4.0,10.0,70.0,200.0/
      data ac1o2l/3.4e-3,3.4e-3,3.3e-3,3.05e-3,2.4e-3,0.6e-3,0.25e-3/
      data u2o3/1.0e-6,7.0e-4,0.4,2.0,7.0,20.0,50.0,100.0/
      data ac2o3l/7.35e-3,7.35e-3,8.35e-3,8.0e-3,7.5e-3,
     * 7.0e-3,6.0e-3,5.5e-3/
!ctar      data u4o2/0.01,0.05,0.1,0.3,1.0,3.0,10.0,100.0/
!ctar      data ac4o2l/1.9e-2,1.8e-2,1.5e-2,1.0e-2,0.7e-2,0.48e-2,
!ctar     * 0.25e-2,0.25e-2/            
!             
!             
      do i=1,m
      do k=1,np
! 
      ac1o3=ac1o3l(1)      
      if (uo3s(i,k).gt.u1o3(22)) ac1o3=ac1o3l(22)
!                 
      do l=1,21      
      if (uo3s(i,k).gt.u1o3(l).and.uo3s(i,k).le.u1o3(l+1)) then 
      ac1o3=ac1o3l(l)+(ac1o3l(l)-ac1o3l(l+1))*(uo3s(i,k)-
     * u1o3(l))/(u1o3(l)-u1o3(l+1)) 
      endif
      enddo
      
!      write (*,*) 'ac1o3='
!      write (*,30) ac1o3
!
      ac1o2=ac1o2l(1)
      if (uo2s(i,k).gt.u1o2(7)) ac1o2=ac1o2l(7) 
      do l=1,6      
      if (uo2s(i,k).gt.u1o2(l).and.uo2s(i,k).le.u1o2(l+1)) then 
      ac1o2=ac1o2l(l)+(ac1o2l(l)-ac1o2l(l+1))*(uo2s(i,k)-
     * u1o2(l))/(u1o2(l)-u1o2(l+1)) 
      endif      
      enddo
!
!      write (*,*) 'ac1o2='
!      write (*,30) ac1o2
      
      acuv(i,k,1)=ac1o3*uo3(i,k)+ac1o2*uo2(i,k)
!
      ac2o3=ac2o3l(1)
      if (uo3s(i,k).gt.u2o3(8)) ac2o3=ac2o3l(8)       
      do l=1,7      
      if (uo3s(i,k).gt.u2o3(l).and.uo3s(i,k).le.u2o3(l+1)) then 
      ac2o3=ac2o3l(l)+(ac2o3l(l)-ac2o3l(l+1))*(uo3s(i,k)-
     * u2o3(l))/(u2o3(l)-u2o3(l+1)) 
      endif      
      enddo
      
!      write (*,*) 'ac2o3='
!      write (*,30) ac2o3      
      
!      
      acuv(i,k,2)=ac2o3*uo3(i,k) 
      acuv(i,k,3)=1.93e-4*uo3(i,k)+2.0e-5*uh2o(i,k)            
!
!tar      ac4o2=ac4o2l(1)
!tar      if (uo2s(i,k).gt.u4o2(8)) ac4o2=ac4o2l(8)
!tar      do l=1,7      
!tar      if (uo2s(i,k).gt.u4o2(l).and.uo2s(i,k).le.u4o2(l+1)) then 
!tar      ac4o2=ac4o2l(l)+(ac4o2l(l)-ac4o2l(l+1))*(uo2s(i,k)-
!tar     * u4o2(l))/(u4o2(l)-u4o2(l+1)) 
!tar      endif      
!tar      enddo
      
!      write (*,*) 'ac4o2='
!      write (*,30) ac4o2      
      
!      
!tar      acuv(i,k,4)=ac4o2*uo2(i,k)            
      
      enddo
      enddo
      
  30   format (1E12.4)
   
      return
      end
      
